Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1714)

Unified Diff: Source/modules/push_messaging/PushSubscriptionCallbacks.h

Issue 841333002: Push API: rename registration to subscription. (Closed) Base URL: svn://svn.chromium.org/blink/trunk
Patch Set: Use https in the spec link. Created 5 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: Source/modules/push_messaging/PushSubscriptionCallbacks.h
diff --git a/Source/modules/push_messaging/PushRegistrationCallbacks.h b/Source/modules/push_messaging/PushSubscriptionCallbacks.h
similarity index 59%
rename from Source/modules/push_messaging/PushRegistrationCallbacks.h
rename to Source/modules/push_messaging/PushSubscriptionCallbacks.h
index 7f93d27205d7e20b43a098da59f3e7200468fcde..75cd6d3ddf727f9ddefb006b9e6f5c5646130daf 100644
--- a/Source/modules/push_messaging/PushRegistrationCallbacks.h
+++ b/Source/modules/push_messaging/PushSubscriptionCallbacks.h
@@ -2,8 +2,8 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#ifndef PushRegistrationCallbacks_h
-#define PushRegistrationCallbacks_h
+#ifndef PushSubscriptionCallbacks_h
+#define PushSubscriptionCallbacks_h
#include "platform/heap/Handle.h"
#include "public/platform/WebCallbacks.h"
@@ -16,19 +16,19 @@ namespace blink {
class ServiceWorkerRegistration;
class ScriptPromiseResolver;
struct WebPushError;
-struct WebPushRegistration;
+struct WebPushSubscription;
-// PushRegistrationCallbacks is an implementation of WebPushRegistrationCallbacks
+// PushSubscriptionCallbacks is an implementation of WebPushSubscriptionCallbacks
// that will resolve the underlying promise depending on the result passed to
// the callback. It takes a ServiceWorkerRegistration in its constructor and
-// will pass it to the PushRegistration.
-class PushRegistrationCallbacks final : public WebCallbacks<WebPushRegistration, WebPushError> {
- WTF_MAKE_NONCOPYABLE(PushRegistrationCallbacks);
+// will pass it to the PushSubscription.
+class PushSubscriptionCallbacks final : public WebCallbacks<WebPushSubscription, WebPushError> {
+ WTF_MAKE_NONCOPYABLE(PushSubscriptionCallbacks);
public:
- PushRegistrationCallbacks(PassRefPtrWillBeRawPtr<ScriptPromiseResolver>, ServiceWorkerRegistration*);
- ~PushRegistrationCallbacks() override;
+ PushSubscriptionCallbacks(PassRefPtrWillBeRawPtr<ScriptPromiseResolver>, ServiceWorkerRegistration*);
+ ~PushSubscriptionCallbacks() override;
- void onSuccess(WebPushRegistration*) override;
+ void onSuccess(WebPushSubscription*) override;
void onError(WebPushError*) override;
private:
@@ -38,4 +38,4 @@ private:
} // namespace blink
-#endif // PushRegistrationCallbacks_h
+#endif // PushSubscriptionCallbacks_h
« no previous file with comments | « Source/modules/push_messaging/PushSubscription.idl ('k') | Source/modules/push_messaging/PushSubscriptionCallbacks.cpp » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698